@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: CloudServices.py 1232 2021-09-06 03:01:02Z Casey $
+# $Id: CloudServices.py 1233 2021-09-07 03:22:45Z Casey $
 #
 # Copyright (c) 2021 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Casey $
-# $Date: 2021-09-06 11:01:02 +0800 (Mon, 06 Sep 2021) $
-# $Revision: 1232 $
+# $Date: 2021-09-07 11:22:45 +0800 (Tue, 07 Sep 2021) $
+# $Revision: 1233 $
 
 import json
 import socket
@@ -387,7 +387,17 @@ class HealthchecksService(BaseServices):
             integrations = ",".join(integrations)
             
         return hchkAPIKey, integrations
-        
+
+    def deleteHealthchecks(self, browser, projectLink):
+        projextCheckUrl = f'{HEALTHCHECKS_URL}{projectLink}checks/'
+        browser.open(projextCheckUrl)
+        for checkUrl in browser.page.select("span.my-checks-url"):
+            # checkUrl.text => https://healthchecks.nuwainfo.com/ping/88e82d0b-d893-44af-b156-9471d1783930
+            checkUrlId = checkUrl.text.split('/ping/')[1].strip(' ').strip('\n')
+            detailUrl = f"{HEALTHCHECKS_URL}/checks/{checkUrlId}/details/"
+            browser.open(detailUrl)
+            browser.select_form(f'form[action="/checks/{checkUrlId}/remove/"]')
+            browser.submit_selected()
 
     def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomainList=None, deleteDnsAndHealthchecks=False):
         # connect 
@@ -395,8 +405,8 @@ class HealthchecksService(BaseServices):
        
         # find project
         hchkProjectName = "[%s] %s" % (companyName, projectName)
-        projectLink = self.findProject(browser, hchkProjectName) 
-        
+        projectLink = self.findProject(browser, hchkProjectName)
+
         if not projectLink:
             browser.select_form('#add-project-modal form')
             browser["name"] = hchkProjectName
@@ -406,6 +416,12 @@ class HealthchecksService(BaseServices):
             
         projectLink = projectLink.replace("checks/", "") # /EX: projects/9e7208d8-8b72-4872-8859-b781ae952b60/checks/
 
+        if deleteDnsAndHealthchecks:
+            self.deleteHealthchecks(browser, projectLink)
+            return {
+                'Deleted Healthchecks': hchkProjectName, 
+            }
+
         # create API
         browser.open("%s/%ssettings" % (HEALTHCHECKS_URL, projectLink))
         for div in browser.page.select("div.panel-body"):
